#!/bin/bash
# $Copyright$
# Copyright 2013-2017 FUJITSU LIMITED
# All rights reserved
#
#
# NAME
#
#   SVdp-LinuxAgents-restart - ServerView Agents Linux Restart Script
#                              for Dynamic Partitioning
#
# SYNOPSIS
#
#
# DESCRIPTION
#
#   This script requires root privileges.
#
# DIAGNOSTICS
#
#   Progress messages are logged to stdout (1), error messages to stderr (2).
#
# EXIT STATUS
#
#   = 0 OK                success
#   > 0 Error             generic or unspecified error
#
# SEE ALSO
#
#   srvmagt(8)
#


echo "start"
while getopts c:d:e:m:n:p:r:v OPT
do
  case $OPT in
    c) CPUNUM="$OPTARG" ;;
    d) PCIADDR="$OPTARG" ;;
    e) EVENT="$OPTARG" ;;
    m) MEMORY="$OPTARG" ;;
    n) NODENUM="$OPTARG" ;;
    p) DEVICE="$OPTARG" ;;
    r) RESULT="$OPTARG" ;;
    v) FLG_V="TRUE" ;;
    *) exit 1 ;;
  esac
done

echo "check options: $DEVICE $EVENT"


#
# Restart Linux Agents if $DEVICE ( is SB or IOU ) and $EVENT is post event
#
result=0
echo $DEVICE | grep "SB-*[[:digit:]]\+" -q
if [ $? -eq 0 ]; then
  if [ "$EVENT" = "ADD_POST" -o "$EVENT" = "RM_POST" ]; then
    echo "restarting ServerView Agents Linux after changing SB configuration"
    /usr/sbin/srvmagt restart
    result=$?
  else
    echo "not a post event -> ignoring"
  fi
else
  echo $DEVICE | grep "IOU-*[[:digit:]]\+" -q
  if [ $? -eq 0 ]; then
    if [ "$EVENT" = "ADD_POST" -o "$EVENT" = "RM_POST" ]; then
      echo "restarting ServerView Agents Linux after changing IOU configuration"
      /usr/sbin/srvmagt restart
      result=$?
    else
      echo "not a post event -> ignoring"
    fi
  else
    echo "not SB and not IOU"
  fi
fi

echo "exit $result"
exit $result


