#!/bin/sh
# $Copyright$
# Copyright 2009-2017 FUJITSU LIMITED
# All rights reserved
#
# NAME
#	SVforceVV - force a rescan of the VersionView database
#
# SYNOPSIS
#	SVforceVV
#
# DESCRIPTION
# 	This script forces the ServerView Agents Linux  VersionView subagent
#	to immediatly rescan the system and to rebuild the VersionView database
#	kept in VersionView.sav (5).
#
#	This command requires root privileges.
#
# SEE ALSO
#	VersionView.sav(5), srvmagt-agent(8)
#
# EXIT STATUS
#	0 OK
#	1 Runtime Error
#	2 Argument error
#
# CHANGE HISTORY
#	Mar 2008, -rit
#		Initial implementation.
   
# ----------------------------------------------------------------------
# Initialization
# ----------------------------------------------------------------------

MYSELF="${0##*/}"

status=0
language=

# Internationalized Messages

USAGE="#### Usage:
    $0
    force a rescan of the VersionView database\n"

AgentNotRunning="The vvagt is not running (there is no PID file).\n"
MustBeBash="You must have the bash to execute this script. Exit!\n"
MustBeRoot="%s: You must be root to execute this program. Exit!\n"

# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

PATH="/bin:/sbin:/usr/bin:/usr/sbin"

[ -n "${BASH}" ] || {
	printf "$MustBeBash"
	exit 1
}

[ $(id -un) = "root" ] || {
	printf "$MustBeRoot" $MYSELF
	exit 1
}

while getopts h optChar; do
	case "$optChar" in
	h|[?])
		printf "$USAGE"
		[ "$1" = "-h" ] && exit 0
		exit 2
		;;
	esac
done

# Send the vvagt a SIGUSR2 signal

pid=
[ -f /var/run/vvagt.pid ] && read pid < /var/run/vvagt.pid
[ -f /etc/srvmagt/vvagt.pid ] && read pid < /etc/srvmagt/vvagt.pid

[ "$pid" ] || {
	printf "$AgentNotRunning"
	exit 1
}

kill -USR2 $pid

status=$?

# ----------------------------------------------------------------------
# Done
# ----------------------------------------------------------------------

exit $status

# EOF
